@@ -1,6 +1,6 @@
 package ACME::MBHall;
 
-use 5.006
+use 5.006;
 use strict;
 use warnings;
 
@@ -10,11 +10,11 @@ ACME::MBHall - The great new ACME::MBHall!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
@@ -35,11 +35,18 @@ if you don't export anything, such as for a purely object-oriented module.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 function1
+=head2 sum( LIST_OF_NUMBERS )
+
+Returns the sum of the numbers.
 
 =cut
 
-sub function1 {
+sub sum {
+	my $sum = 0;
+	foreach my $value (@_) {
+		$sum+=$value;
+	}
+	return $sum;
 }
 
 =head2 function2
